Learn R Programming

ESTER (version 0.1.0)

ictab: Computes Akaike weights for a set of models

Description

Returns a table with Akaike weights of a set of models, based on various information criteria. Currently, ictab supports the computation of Akaike weights from the aic or the bic computed on lm or merMod models.

Usage

ictab(ic, ...)

Arguments

ic

Indicates which information criterion to use.

...

A set of models of class lm or merMod.

References

Burnham, K. P., \& Anderson, D. R. (2002). Model Selection and Multimodel Inference: A Practical Information-Theoretical Approach. 2d ed. New York: Springer-Verlag.

Burnham, K. P., \& Anderson, D. R. (2004). Multimodel inference: Understanding AIC and BIC in model selection. Sociological Methods and Research, 33(2), 261-304.

See Also

aic, bic

Examples

Run this code
# NOT RUN {
data(mtcars)
mod1 <- lm(mpg ~ cyl, mtcars)
mod2 <- lm(mpg ~ cyl + vs, mtcars)
mod3 <- lm(mpg ~ cyl + vs + I(vs^2), mtcars)
mod4 <- lm(mpg ~ cyl * vs, mtcars)
ictab(aic, mod1, mod2, mod3, mod4)
ictab(bic, mod1, mod2, mod3, mod4)

# }

Run the code above in your browser using DataLab